@@ -36,7 +36,7 @@ headers = {
     'Content-Type': 'application/json'
 }
 url = 'http://127.0.0.1:5010/options'
-url_ltp = 'http://0.0.0.0:5010/get_price'
+url_ltp = 'http://localhost:5010/get_price'
 url_order_status = 'http://127.0.0.1:5010/get_order'
 
 
